@@ -200,7 +200,10 @@ bool PublicationSet::exportPublicationSetToBibTeX(PublicationSet* publicationSet
       const Node* publication = publicationSet->get(index);
       if(publication->value == "Comment") {
          if(fh != nullptr) {
-            fprintf(fh, "%%%s\n\n", publication->keyword.c_str());
+            Node* child = publication->child;
+            if(child != nullptr) {
+               fprintf(fh, "%%%s\n\n", child->value.c_str());
+            }
          }
       }
       else {
@@ -534,7 +537,6 @@ inline static std::string getNextAction(const char* inputString, size_t& counter
    if(inputString[0] == '{') {
       std::string input((const char*)&inputString[1]);
       result = extractToken(input, std::string("}"));
-      std::transform(result.begin(), result.end(), result.begin(), ::tolower);
       counter += result.size() + 1;
    }
    else {
